@@ -93,15 +93,41 @@ function authenticateFido2() {
         }),
       });
     })
-    .then(() => {
-      const urlParams = new URLSearchParams(window.location.search);
-      const nextParam = urlParams.get("next");
-      if (nextParam) {
-        window.location = nextParam;
-      } else {
-        window.location = "../../";
-      }
-    });
+    .then(() => checkForRemember())
+    .then(() => redirectToNext());
+}
+
+function checkForRemember() {
+  const remember = document.getElementById("remember").checked;
+  if (remember) {
+    const trustedDeviceURL = "/mfa/user_keys/trusted_device/";
+    return fetch(trustedDeviceURL)
+      .then((response) => response.json())
+      .then((userKey) => {
+        const expire = new Date();
+        expire.setTime(expire.getTime() + 1000 * 86400 * 180); // 180 days
+        document.cookie = `remember_device_key=${userKey.key}; expires=${expire}; path=/`;
+        return fetch(trustedDeviceURL, {
+          method: "POST",
+          headers: {
+            "Content-Type": "application/json",
+            "X-CSRFToken": getCookie("csrftoken"),
+          },
+          body: JSON.stringify({key: userKey.key})
+        })
+    })
+  }
+  return new Promise();
+}
+
+function redirectToNext() {
+  const urlParams = new URLSearchParams(window.location.search);
+  const nextParam = urlParams.get("next");
+  if (nextParam) {
+    window.location = nextParam;
+  } else {
+    window.location = "../../";
+  }
 }
 
 function registerTOTPStart() {
@@ -142,19 +168,11 @@ function authenticateTOTP(otp) {
   })
     .then((response) => {
       if (response.ok) {
-        const urlParams = new URLSearchParams(window.location.search);
-        const nextParam = urlParams.get("next");
-        if (nextParam) {
-          window.location = nextParam;
-        } else {
-          window.location = "../../";
-        }
+        checkForRemember().then(() => redirectToNext())
       } else {
         throw new Error("Invalid OTP")
       }
     })
-    .then(() => {
-    })
     .catch((err) => {
       alert(err);
     });
